TODO
===

- price_tracker
- time_tracker
- scheduling

Bootstrap
===

- generate sqlite3 DB: `./manage.py migrate`
- create admin superuser: `./manage.py createsuperuser`
- run server: `./manage.py runserver`